==> igniteui-angular-charts-17.2.1.tgz: package/esm5/lib/Stacked100BarSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StackedBarSeries } from "./StackedBarSeries";
import { IStacked100Series_$type } from "./IStacked100Series";
import { Defaults } from "./Defaults";
import { markType } from "igniteui-angular-core";
import { Stacked100DataPreparer } from "./Stacked100DataPreparer";
import { isNaN_ } from "igniteui-angular-core";
import { StackedBarSeriesView } from "./StackedBarSeriesView";
import { Stacked100BarBucketCalculator } from "./Stacked100BarBucketCalculator";
/**
 * @hidden
 */
var Stacked100BarSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(Stacked100BarSeries, _super);
    function Stacked100BarSeries() {
        var _this = _super.call(this) || this;
        _this.ab = Stacked100BarSeries.$;
        return _this;
    }
    Stacked100BarSeries.prototype.get_xo = function () {
        return true;
    };
    Stacked100BarSeries.prototype.iq = function () {
        if (!isNaN_(this.ip)) {
            return _super.prototype.iq.call(this);
        }
        return Defaults.h;
    };
    Stacked100BarSeries.prototype.ac = function () {
        _super.prototype.ac.call(this);
        this.pq(false);
    };
    Stacked100BarSeries.prototype.ch = function () {
        return new Stacked100BarSeriesView(this);
    };
    Stacked100BarSeries.prototype.o1 = function (a) {
        _super.prototype.o1.call(this, a);
        this.ys = a;
    };
    Stacked100BarSeries.prototype.xg = function () {
        return this.ys;
    };
    Stacked100BarSeries.prototype.x4 = function () {
        _super.prototype.x4.call(this);
        Stacked100DataPreparer.a(this);
    };
    Object.defineProperty(Stacked100BarSeries.prototype, "useHighMarkerFidelity", {
        get: function () {
            return this.wj;
        },
        enumerable: false,
        configurable: true
    });
    Stacked100BarSeries.$t = markType(Stacked100BarSeries, 'Stacked100BarSeries', StackedBarSeries.$, [IStacked100Series_$type]);
    return Stacked100BarSeries;
}(StackedBarSeries));
export { Stacked100BarSeries };
/**
 * @hidden
 */
var Stacked100BarSeriesView = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(Stacked100BarSeriesView, _super);
    function Stacked100BarSeriesView(a) {
        var _this = _super.call(this, a) || this;
        _this.c9 = null;
        _this.c9 = a;
        return _this;
    }
    Stacked100BarSeriesView.prototype.cv = function () {
        return new Stacked100BarBucketCalculator(this);
    };
    Stacked100BarSeriesView.prototype.au = function () {
        _super.prototype.au.call(this);
        if (!this.q) {
            this.c3.ub = Defaults.c;
            this.c3.iv = Defaults.i;
        }
    };
    Stacked100BarSeriesView.$t = markType(Stacked100BarSeriesView, 'Stacked100BarSeriesView', StackedBarSeriesView.$);
    return Stacked100BarSeriesView;
}(StackedBarSeriesView));
export { Stacked100BarSeriesView };

==> igniteui-angular-charts-17.3.0.tgz: package/esm5/lib/Stacked100BarSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StackedBarSeries } from "./StackedBarSeries";
import { IStacked100Series_$type } from "./IStacked100Series";
import { Defaults } from "./Defaults";
import { markType } from "igniteui-angular-core";
import { Stacked100DataPreparer } from "./Stacked100DataPreparer";
import { isNaN_ } from "igniteui-angular-core";
import { StackedBarSeriesView } from "./StackedBarSeriesView";
import { Stacked100BarBucketCalculator } from "./Stacked100BarBucketCalculator";
/**
 * @hidden
 */
var Stacked100BarSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(Stacked100BarSeries, _super);
    function Stacked100BarSeries() {
        var _this = _super.call(this) || this;
        _this.ab = Stacked100BarSeries.$;
        return _this;
    }
    Stacked100BarSeries.prototype.get_xp = function () {
        return true;
    };
    Stacked100BarSeries.prototype.iq = function () {
        if (!isNaN_(this.ip)) {
            return _super.prototype.iq.call(this);
        }
        return Defaults.h;
    };
    Stacked100BarSeries.prototype.ac = function () {
        _super.prototype.ac.call(this);
        this.pr(false);
    };
    Stacked100BarSeries.prototype.cd = function () {
        return new Stacked100BarSeriesView(this);
    };
    Stacked100BarSeries.prototype.o2 = function (a) {
        _super.prototype.o2.call(this, a);
        this.yt = a;
    };
    Stacked100BarSeries.prototype.xh = function () {
        return this.yt;
    };
    Stacked100BarSeries.prototype.x5 = function () {
        _super.prototype.x5.call(this);
        Stacked100DataPreparer.a(this);
    };
    Object.defineProperty(Stacked100BarSeries.prototype, "useHighMarkerFidelity", {
        get: function () {
            return this.wk;
        },
        enumerable: false,
        configurable: true
    });
    Stacked100BarSeries.$t = markType(Stacked100BarSeries, 'Stacked100BarSeries', StackedBarSeries.$, [IStacked100Series_$type]);
    return Stacked100BarSeries;
}(StackedBarSeries));
export { Stacked100BarSeries };
/**
 * @hidden
 */
var Stacked100BarSeriesView = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(Stacked100BarSeriesView, _super);
    function Stacked100BarSeriesView(a) {
        var _this = _super.call(this, a) || this;
        _this.c9 = null;
        _this.c9 = a;
        return _this;
    }
    Stacked100BarSeriesView.prototype.cv = function () {
        return new Stacked100BarBucketCalculator(this);
    };
    Stacked100BarSeriesView.prototype.au = function () {
        _super.prototype.au.call(this);
        if (!this.q) {
            this.c3.uc = Defaults.c;
            this.c3.iv = Defaults.i;
        }
    };
    Stacked100BarSeriesView.$t = markType(Stacked100BarSeriesView, 'Stacked100BarSeriesView', StackedBarSeriesView.$);
    return Stacked100BarSeriesView;
}(StackedBarSeriesView));
export { Stacked100BarSeriesView };
